@@ -1,7 +1,9 @@
 context("link input")
 
 test_that("id argument", {
+  expect_error(linkInput(), "please specify `id`")
   expect_error(linkInput(id = 2, "TEXT"))
+
   expect_silent(linkInput(id = "ID", "TEXT"))
 })
 
@@ -14,3 +16,7 @@ test_that("download argument", {
     tag_name_is(linkInput(id = "ID", "TEXT", download = TRUE), "a")
   )
 })
+
+test_that("has dependencies", {
+  expect_dependencies(linkInput("ID", "LABEL"))
+})
